==> ATutor-1.5.3.tar.gz: ATutor/themes/default/theme.cfg.php <==
<?php
/************************************************************************/
/* ATutor																*/
/************************************************************************/
/* Copyright (c) 2002-2006 by Greg Gay, Joel Kronenberg & Heidi Hazelton*/
/* Adaptive Technology Resource Centre / University of Toronto			*/
/* http://atutor.ca														*/
/*																		*/
/* This program is free software. You can redistribute it and/or		*/
/* modify it under the terms of the GNU General Public License			*/
/* as published by the Free Software Foundation.						*/
/************************************************************************/
// $Id: theme.cfg.php 6481 2006-07-06 15:03:02Z joel $

/* This is the default configuration file for the default theme. */

/* The theme's name. */
	$_theme['name'] = 'ATutor';

/* The theme's version number. */
	$_theme['version'] = '0.2';

/* Which version of ATutor is this theme intended for. */
	$_theme['atutor-version'] = '1.5.3';

/* author information */
	$_theme['author_name']  = 'ATutor';
	$_theme['author_url']   = 'http://atutor.ca';
	$_theme['author_email'] = '';

/* theme default course banner styles: */
	$_theme['banner']['font-family'] = 'Verdana, Arial, sans-serif';
	$_theme['banner']['font-weight'] = 'bold';
	$_theme['banner']['color']       = 'black';
	$_theme['banner']['font-size']   = 'xx-large';
	$_theme['banner']['text-align']  = 'center';

	$_theme['banner']['background-color'] = 'white';
	$_theme['banner']['background-image'] = '';
	$_theme['banner']['vertical-align']   = 'middle';
	$_theme['banner']['padding']          = '3px';

?>

==> ATutor-1.6.tar.gz: ATutor/themes/default/theme.cfg.php <==
<?php
/************************************************************************/
/* ATutor																*/
/************************************************************************/
/* Copyright (c) 2002-2008 by Greg Gay, Joel Kronenberg & Heidi Hazelton*/
/* Adaptive Technology Resource Centre / University of Toronto			*/
/* http://atutor.ca														*/
/*																		*/
/* This program is free software. You can redistribute it and/or		*/
/* modify it under the terms of the GNU General Public License			*/
/* as published by the Free Software Foundation.						*/
/************************************************************************/

// $Id: theme.cfg.php 2813 2004-12-12 15:37:46Z greg $

/* This is the default configuration file for the default theme. */

/* The theme's name. */
	$_theme['name'] = 'Default 1.6';

/* The theme's version number. */
	$_theme['version'] = '0.1';

/* Which version of ATutor is this theme intended for. */
	$_theme['atutor-version'] = '1.6';

/* author information */
	$_theme['author_name']  = 'ATutor';
	$_theme['author_url']   = 'http://atutor.ca';
	$_theme['author_email'] = '';

/* theme default course banner styles: */
	$_theme['banner']['font-family'] = 'Verdana, Arial, sans-serif';
	$_theme['banner']['font-weight'] = 'bold';
	$_theme['banner']['color']       = 'black';
	$_theme['banner']['font-size']   = 'xx-large';
	$_theme['banner']['text-align']  = 'center';

	$_theme['banner']['background-color'] = 'white';
	$_theme['banner']['background-image'] = '';
	$_theme['banner']['vertical-align']   = 'middle';
	$_theme['banner']['padding']          = '3px';

?>
